@@ -1,10 +1,11 @@
+use swc_common::{BytePos, Spanned};
+use swc_css_ast::*;
+
 use super::{input::ParserInput, Ctx, PResult, Parser};
 use crate::{
     error::{Error, ErrorKind},
     Parse,
 };
-use swc_common::{BytePos, Spanned};
-use swc_css_ast::*;
 
 #[cfg(test)]
 mod tests;
@@ -45,7 +46,7 @@ where
                     "function",
                     "ident",
                     "dimension",
-                    "percent",
+                    "percentage",
                     "num",
                     "str",
                     "#",
@@ -267,7 +268,7 @@ where
                 return Ok(Value::Function(self.parse()?));
             }
 
-            tok!("percent") | tok!("dimension") | tok!("num") => {
+            tok!("percentage") | tok!("dimension") | tok!("num") => {
                 let span = self.input.cur_span()?;
                 let base = self.parse_basical_numeric_value()?;
 
@@ -390,7 +391,7 @@ where
 
     fn parse_basical_numeric_value(&mut self) -> PResult<Value> {
         match cur!(self) {
-            tok!("percent") => Ok(Value::Percent(self.parse()?)),
+            tok!("percentage") => Ok(Value::Percentage(self.parse()?)),
             tok!("dimension") => Ok(Value::Dimension(self.parse()?)),
             tok!("num") => Ok(Value::Number(self.parse()?)),
             _ => {
@@ -1063,26 +1064,26 @@ where
     }
 }
 
-impl<I> Parse<Percent> for Parser<I>
+impl<I> Parse<Percentage> for Parser<I>
 where
     I: ParserInput,
 {
-    fn parse(&mut self) -> PResult<Percent> {
+    fn parse(&mut self) -> PResult<Percentage> {
         let span = self.input.cur_span()?;
 
-        if !is!(self, Percent) {
-            return Err(Error::new(span, ErrorKind::Expected("Percent")));
+        if !is!(self, Percentage) {
+            return Err(Error::new(span, ErrorKind::Expected("percentage token")));
         }
 
         match bump!(self) {
-            Token::Percent { value, raw } => {
+            Token::Percentage { value, raw } => {
                 let value = Number {
                     span: swc_common::Span::new(span.lo, span.hi - BytePos(1), Default::default()),
                     value,
                     raw,
                 };
 
-                Ok(Percent { span, value })
+                Ok(Percentage { span, value })
             }
             _ => {
                 unreachable!()
@@ -1327,9 +1328,8 @@ where
 }
 
 fn is_length_unit(unit: &str) -> bool {
-    match &*unit.to_ascii_lowercase() {
-        // Relative Lengths
-        // Font-relative Lengths
+    matches!(
+        &*unit.to_ascii_lowercase(),
         "em" | "rem"  | 
         "ex" | "rex" | 
         "cap" | "rcap" | 
@@ -1344,42 +1344,26 @@ fn is_length_unit(unit: &str) -> bool {
         "vmin" | "svmin" | "lvmin" | "dvmin" |
         "vmax" | "svmax" | "lvmax" | "dvmax" |
         // Absolute lengths
-        "cm" | "mm" | "q" | "in" | "pc" | "pt" | "px" | "mozmm" => true,
-        _ => false,
-    }
+        "cm" | "mm" | "q" | "in" | "pc" | "pt" | "px" | "mozmm"
+    )
 }
 
 fn is_angle_unit(unit: &str) -> bool {
-    match &*unit.to_ascii_lowercase() {
-        "deg" | "grad" | "rad" | "turn" => true,
-        _ => false,
-    }
+    matches!(&*unit.to_ascii_lowercase(), "deg" | "grad" | "rad" | "turn")
 }
 
 fn is_time_unit(unit: &str) -> bool {
-    match &*unit.to_ascii_lowercase() {
-        "s" | "ms" => true,
-        _ => false,
-    }
+    matches!(&*unit.to_ascii_lowercase(), "s" | "ms")
 }
 
 fn is_frequency_unit(unit: &str) -> bool {
-    match &*unit.to_ascii_lowercase() {
-        "hz" | "khz" => true,
-        _ => false,
-    }
+    matches!(&*unit.to_ascii_lowercase(), "hz" | "khz")
 }
 
 fn is_resolution_unit(unit: &str) -> bool {
-    match &*unit.to_ascii_lowercase() {
-        "dpi" | "dpcm" | "dppx" | "x" => true,
-        _ => false,
-    }
+    matches!(&*unit.to_ascii_lowercase(), "dpi" | "dpcm" | "dppx" | "x")
 }
 
 fn is_flex_unit(unit: &str) -> bool {
-    match &*unit.to_ascii_lowercase() {
-        "fr" => true,
-        _ => false,
-    }
+    matches!(&*unit.to_ascii_lowercase(), "fr")
 }
